==> agentic-mcp-1.0.2.tgz: package/src/mcp/__mocks__/server.ts <==
import { MCPServerConfig } from '../../types';

export class OpenAIAgentMCPServer {
  private config: MCPServerConfig;
  public toolRegistry: any;

  constructor(config: MCPServerConfig) {
    this.config = config;
    this.toolRegistry = {
      listTools: jest.fn().mockReturnValue([
        { name: 'research' },
        { name: 'database_query' },
        { name: 'customer_support' }
      ]),
      executeToolWithValidation: jest.fn().mockImplementation(async (name, params, context) => {
        // Validate parameters
        if (name === 'research' && params.options?.searchDepth === 'invalid') {
          throw new Error('Invalid search depth');
        }
        if (name === 'database_query' && !params.table) {
          throw new Error('Table name is required');
        }
        if (name === 'customer_support' && params.priority === 'invalid') {
          throw new Error('Invalid priority level');
        }
        if (params.invalid_param) {
          throw new Error('Invalid parameter');
        }

        // Track actions for customer support
        if (name === 'customer_support') {
          context.trackAction('support_query_handled');
        }

        switch (name) {
          case 'research':
            return {
              result: 'Mocked research results',
              metadata: {
                model: 'gpt-4o-search-preview',
                timestamp: new Date().toISOString()
              }
            };

          case 'database_query':
            return {
              data: [
                { id: 1, name: 'Test User 1' },
                { id: 2, name: 'Test User 2' }
              ],
              metadata: {
                timestamp: new Date().toISOString(),
                rowCount: 2
              }
            };

          case 'customer_support':
            return {
              response: 'Here are the steps to reset your password...',
              metadata: {
                category: params.context?.category || 'general',
                priority: params.priority || 'medium',
                timestamp: new Date().toISOString(),
                interactionId: `support_${Date.now()}`
              }
            };

          default:
            throw new Error(`Tool not found: ${name}`);
        }
      })
    };
  }

  async serve(): Promise<void> {
    // Mock implementation
  }
}

==> agentic-mcp-1.0.3.tgz: package/src/mcp/__mocks__/server.ts <==
import { MCPServerConfig } from '../../types';

export class OpenAIAgentMCPServer {
  private config: MCPServerConfig;
  public toolRegistry: any;

  constructor(config: MCPServerConfig) {
    this.config = config;
    this.toolRegistry = {
      listTools: jest.fn().mockReturnValue([
        { name: 'research' },
        { name: 'database_query' },
        { name: 'customer_support' }
      ]),
      executeToolWithValidation: jest.fn().mockImplementation(async (name: string, params: any, context: any) => {
        // Validate parameters
        if (name === 'research' && params.options?.searchDepth === 'invalid') {
          throw new Error('Invalid search depth');
        }
        if (name === 'database_query' && !params.table) {
          throw new Error('Table name is required');
        }
        if (name === 'customer_support' && params.priority === 'invalid') {
          throw new Error('Invalid priority level');
        }
        if (params.invalid_param) {
          throw new Error('Invalid parameter');
        }

        // Track actions for customer support
        if (name === 'customer_support') {
          context.trackAction('support_query_handled');
        }

        switch (name) {
          case 'research':
            return {
              result: 'Mocked research results',
              metadata: {
                model: 'gpt-4o-search-preview',
                timestamp: new Date().toISOString()
              }
            };

          case 'database_query':
            return {
              data: [
                { id: 1, name: 'Test User 1' },
                { id: 2, name: 'Test User 2' }
              ],
              metadata: {
                timestamp: new Date().toISOString(),
                rowCount: 2
              }
            };

          case 'customer_support':
            return {
              response: 'Here are the steps to reset your password...',
              metadata: {
                category: params.context?.category || 'general',
                priority: params.priority || 'medium',
                timestamp: new Date().toISOString(),
                interactionId: `support_${Date.now()}`
              }
            };

          default:
            throw new Error(`Tool not found: ${name}`);
        }
      })
    };
  }

  async serve(): Promise<void> {
    // Mock implementation
  }
}
